pub fn tool_batch(
calls: &[(&str, &str, Value)],
) -> Vec<Result<StreamEvent, ProviderError>>Expand description
A one-sample script whose assistant turn calls several tools in one batch.
pub fn tool_batch(
calls: &[(&str, &str, Value)],
) -> Vec<Result<StreamEvent, ProviderError>>A one-sample script whose assistant turn calls several tools in one batch.